@@ -5,9 +5,7 @@ prepare_autoplot = function(resampling_type, task = NULL, ...) {
   if (is.null(task)) {
     task = test_make_twoclass_task()
   }
-  rsp = rsmp(resampling_type, ...)
-  rsp$instantiate(task)
-
+  rsp = rsmp(resampling_type, ...)$instantiate(task)
 
   return(list(rsp = rsp, task = task))
 }
