@@ -21,8 +21,8 @@ test_that("plot() works for 'sptcv_cstf' 2D - time_var", {
       sample_fold_n = 3L)
   )
 
-  expect_true(is.ggplot(p1))
-  expect_true(is.ggplot(p2))
+  expect_true(is_ggplot(p1))
+  expect_true(is_ggplot(p2))
   expect_list(p3)
 
   p4 = autoplot(rsp, tsk_cookfarm_sub, repeats_id = 2, sample_fold_n = 3L)
@@ -64,8 +64,8 @@ test_that("plot() works for 'sptcv_cstf' 2D - space_var", {
   # plot() would force image printing here
   p3 = autoplot(rsp, tsk_cookfarm_sub, c(1, 2), sample_fold_n = 3L)
 
-  expect_true(is.ggplot(p1))
-  expect_true(is.ggplot(p2))
+  expect_true(is_ggplot(p1))
+  expect_true(is_ggplot(p2))
   expect_list(p3)
 
   p4 = autoplot(rsp, tsk_cookfarm_sub, repeats_id = 2, sample_fold_n = 3L)
@@ -230,10 +230,10 @@ test_that("plot() works for 'spcv_disc'", {
     autoplot(rsp, task, 1, show_omitted = TRUE)
   )
 
-  expect_true(is.ggplot(p1))
-  expect_true(is.ggplot(p2))
+  expect_true(is_ggplot(p1))
+  expect_true(is_ggplot(p2))
   expect_list(p3)
-  expect_true(is.ggplot(p4))
+  expect_true(is_ggplot(p4))
 
   p5 = autoplot(rsp, task, repeats_id = 2)
   p6 = autoplot(rsp, task, fold_id = 1, repeats_id = 2)
@@ -258,6 +258,43 @@ test_that("plot() works for 'spcv_disc'", {
   vdiffr::expect_doppelganger("RepSpCVDisc - Fold 1-2 - sample_fold_n", p9)
 })
 
+test_that("train_color and test_color parameters work for resampling methods", {
+  skip_if_not_installed("ggplot2")
+  
+  set.seed(42)
+  
+  task = tsk("ecuador")
+  
+  # Test spcv_disc
+  rsp_disc = rsmp("spcv_disc", folds = 4, radius = 200, buffer = 200)
+  rsp_disc$instantiate(task)
+  
+  p_disc = autoplot(rsp_disc, task, fold_id = 1, train_color = "red", test_color = "green")
+  
+  expect_true(is_ggplot(p_disc))
+  
+  # Extract the color scale to verify colors
+  build_disc = ggplot2::ggplot_build(p_disc)
+  colors_disc = build_disc$plot$scales$scales[[1]]$palette(2)
+  
+  expect_equal(unname(colors_disc[1]), "red")  # Train color
+  expect_equal(unname(colors_disc[2]), "green") # Test color
+  
+  # Test spcv_tiles
+  rsp_tiles = rsmp("spcv_tiles", nsplit = c(2L, 2L))
+  rsp_tiles$instantiate(task)
+  
+  p_tiles = autoplot(rsp_tiles, task, fold_id = 1, train_color = "blue", test_color = "orange")
+  
+  expect_true(is_ggplot(p_tiles))
+  
+  build_tiles = ggplot2::ggplot_build(p_tiles)
+  colors_tiles = build_tiles$plot$scales$scales[[1]]$palette(2)
+  
+  expect_equal(unname(colors_tiles[1]), "blue")  # Train color
+  expect_equal(unname(colors_tiles[2]), "orange") # Test color
+})
+
 # spcv_tiles --------------------------------------------------------------------
 
 test_that("plot() works for 'spcv_tiles'", {
@@ -284,10 +321,10 @@ test_that("plot() works for 'spcv_tiles'", {
     autoplot(rsp, task, 1, show_omitted = TRUE)
   )
 
-  expect_true(is.ggplot(p1))
-  expect_true(is.ggplot(p2))
+  expect_true(is_ggplot(p1))
+  expect_true(is_ggplot(p2))
   expect_list(p3)
-  expect_true(is.ggplot(p4))
+  expect_true(is_ggplot(p4))
 
   p5 = autoplot(rsp, task, c(1, 2), repeats_id = 2)
   p6 = autoplot(rsp, task, fold_id = 1, repeats_id = 2)
@@ -337,8 +374,8 @@ test_that("plot() works for 'spcv_knndm'", {
   p3 = autoplot(rsp, task, c(1, 2))
 
 
-  expect_true(is.ggplot(p1))
-  expect_true(is.ggplot(p2))
+  expect_true(is_ggplot(p1))
+  expect_true(is_ggplot(p2))
   expect_list(p3)
 
   p5 = autoplot(rsp, task, repeats_id = 2)
@@ -362,3 +399,33 @@ test_that("plot() works for 'spcv_knndm'", {
   vdiffr::expect_doppelganger("RepSpCVKnndm - Fold 1 - sample_fold_n", p8)
   vdiffr::expect_doppelganger("RepSpCVKnndm - Fold 1-2 - sample_fold_n", p9)
 })
+
+# spcv_disc custom colors test ------------------------------------------------
+
+test_that("train_color and test_color parameters work for 'spcv_disc'", {
+  skip_if_not_installed("blockCV")
+  set.seed(42)
+
+  task = tsk("ecuador")
+  rsmp_disc = rsmp("spcv_disc", folds = 100, radius = 200L, buffer = 400L)
+  rsmp_disc$instantiate(task)
+
+  # Test custom colors - this should work without errors
+  p_custom = autoplot(rsmp_disc, task = task, fold_id = 1, show_omitted = FALSE,
+                     train_color = "red", test_color = "green")
+  
+  expect_true(is_ggplot(p_custom))
+  
+  # Check that the plot has the correct color scales
+  expect_true("ScaleDiscrete" %in% class(p_custom$scales$scales[[1]]))
+  
+  # Test that the plot builds without error
+  expect_no_error(ggplot_build(p_custom))
+  
+  # Test multiple folds with custom colors
+  p_multi = autoplot(rsmp_disc, task = task, fold_id = c(1, 2), 
+                    train_color = "red", test_color = "green")
+  
+  expect_true(is_ggplot(p_multi))
+  expect_no_error(ggplot_build(p_multi))
+})
